===============
Release History
===============

Initial Release (2021-10-17)
----------------------------

* Published the library to PyPi.
* Currently only huggingface's pre-trained models have been partially incorporated.
* Currently we do not recommend using this for any production environment.